@@ -2,7 +2,8 @@ class AppVersionConfig(object):
     STR_TEMPLATE = """AppVersionConfig(
             primary={primary},
             secondary={secondary},
-            tertiary={tertiary}
+            tertiary={tertiary},
+            quaternary={quaternary}
         )"""
 
     def __init__(self, version):
@@ -11,14 +12,17 @@ class AppVersionConfig(object):
         :type version: str
         """
         dissected = version.split('.')
-        assert len(dissected) > 2, "version must be in format x.y.z"
-        self._primary, self._secondary, self._tertiary = map(lambda v:int(v), dissected)
+        padded = dissected + ['0'] * (4 - len(dissected))
+        assert len(padded) == 4, "%s is not a valid version" % version
+
+        self._primary, self._secondary, self._tertiary, self._quaternary = map(lambda v:int(v), padded)
 
     def __str__(self):
         return self.STR_TEMPLATE.format(
             primary=self.primary,
             secondary=self.secondary,
-            tertiary=self.tertiary
+            tertiary=self.tertiary,
+            quaternary=self.quaternary
         )
 
     @property
@@ -32,3 +36,7 @@ class AppVersionConfig(object):
     @property
     def tertiary(self):
         return self._tertiary
+
+    @property
+    def quaternary(self):
+        return self._quaternary
